# -*- coding: utf-8 -*-

__author__ = 'leon'

from .util import utf8


class ElongException(Exception):
    """Base exception class used by :mod:`~pyelong`"""


class RetryableException(ElongException):
    """可以重试的异常，如网络连接错误等"""


class ElongAPIError(ElongException):
    """如果返回值的 `code` 不为 `0`，则 API 调用发生异常"""

    def __init__(self, code, message):
        self.code = utf8(code)
        self.message = utf8(message)

        super(ElongAPIError, self).__init__(message)

    def __str__(self):
        return '<ElongAPIError ("%s", "%s")>' % (self.code, self.message)


class RetryableAPIError(ElongAPIError):
    """可以重试的 API 错误"""



# -*- coding: utf-8 -*-

__author__ = 'leon'

from ..base import ApiBase


class Lowest(ApiBase):
    _category = 'ihotel'

    def price(self, **kwargs):
        """国际酒店最低价列表

        文档
        ~~~~
            - http://open.elong.com/wiki/Ihotel.lowest.price

        NOTE:
        ~~~~
            - 获取API中缓存的酒店的最低价
        """

        return self._request('price', raw=True, **kwargs)



# -*- coding: utf-8 -*-

__version__ = '0.5.0'

__all__ = ('Client', 'Request', 'Response')

from .client import Client
from .request import Request
from .response import Response

# Set default logging handler to avoid "No handler found" warnings.
import logging

try:
    from logging import NullHandler
except ImportError:
    class NullHandler(logging.Handler):
        def emit(self, record):
            pass

logging.getLogger(__name__).addHandler(NullHandler())
